#!/usr/bin/env python

from distutils.core import setup

setup(name='pysheds',
      version='0.1',
      description='🌎 Simple and fast watershed delineation in python.',
      author='Matt Bartos',
      author_email='mdbartos@umich.edu',
      url='http://open-storm.org',
      packages=["pysheds"],
     )
